@@ -1,102 +1,20 @@
 #!/usr/bin/env python
 import setuptools
 import os, sys, os.path, glob, \
-  tempfile, subprocess, shutil
+    tempfile, subprocess, shutil
+from yt.utilities.setup import \
+    check_for_dependencies
+
 
 def check_for_png():
-    # First up: HDF5_DIR in environment
-    if "PNG_DIR" in os.environ:
-        png_dir = os.environ["PNG_DIR"]
-        png_inc = os.path.join(png_dir, "include")
-        png_lib = os.path.join(png_dir, "lib")
-        print "PNG_LOCATION: PNG_DIR: %s, %s" % (png_inc, png_lib)
-        return (png_inc, png_lib)
-    # Next up, we try png.cfg
-    elif os.path.exists("png.cfg"):
-        png_dir = open("png.cfg").read().strip()
-        png_inc = os.path.join(png_dir, "include")
-        png_lib = os.path.join(png_dir, "lib")
-        print "PNG_LOCATION: png.cfg: %s, %s" % (png_inc, png_lib)
-        return (png_inc, png_lib)
-    # Now we see if ctypes can help us:
-    try:
-        import ctypes.util
-        png_libfile = ctypes.util.find_library("png")
-        if png_libfile is not None and os.path.isfile(png_libfile):
-            # Now we've gotten a library, but we'll need to figure out the
-            # includes if this is going to work.  It feels like there is a
-            # better way to pull off two directory names.
-            png_dir = os.path.dirname(os.path.dirname(png_libfile))
-            if os.path.isdir(os.path.join(png_dir, "include")) and \
-               os.path.isfile(os.path.join(png_dir, "include", "png.h")):
-                png_inc = os.path.join(png_dir, "include")
-                png_lib = os.path.join(png_dir, "lib")
-                print "PNG_LOCATION: png found in: %s, %s" % (png_inc, png_lib)
-                return png_inc, png_lib
-    except ImportError:
-        pass
-    # X11 is where it's located by default on OSX, although I am slightly
-    # reluctant to link against that one.
-    for png_dir in ["/usr/", "/usr/local/", "/usr/X11/"]:
-        if os.path.isfile(os.path.join(png_dir, "include", "png.h")):
-            if os.path.isdir(os.path.join(png_dir, "include")) and \
-               os.path.isfile(os.path.join(png_dir, "include", "png.h")):
-                png_inc = os.path.join(png_dir, "include")
-                png_lib = os.path.join(png_dir, "lib")
-                print "PNG_LOCATION: png found in: %s, %s" % (png_inc, png_lib)
-                return png_inc, png_lib
-    print "Reading png location from png.cfg failed."
-    print "Please place the base directory of your png install in png.cfg and restart."
-    print "(ex: \"echo '/usr/local/' > png.cfg\" )"
-    sys.exit(1)
+    return check_for_dependencies("PNG_DIR", "png.cfg", "png.h", "png")
+
 
 def check_for_freetype():
-    # First up: environment
-    if "FTYPE_DIR" in os.environ:
-        freetype_dir = os.environ["FTYPE_DIR"]
-        freetype_inc = os.path.join(freetype_dir, "include")
-        freetype_lib = os.path.join(freetype_dir, "lib")
-        print "FTYPE_LOCATION: FTYPE_DIR: %s, %s" % (freetype_inc, freetype_lib)
-        return (freetype_inc, freetype_lib)
-    # Next up, we try freetype.cfg
-    elif os.path.exists("freetype.cfg"):
-        freetype_dir = open("freetype.cfg").read().strip()
-        freetype_inc = os.path.join(freetype_dir, "include")
-        freetype_lib = os.path.join(freetype_dir, "lib")
-        print "FTYPE_LOCATION: freetype.cfg: %s, %s" % (freetype_inc, freetype_lib)
-        return (freetype_inc, freetype_lib)
-    # Now we see if ctypes can help us:
-    try:
-        import ctypes.util
-        freetype_libfile = ctypes.util.find_library("freetype")
-        if freetype_libfile is not None and os.path.isfile(freetype_libfile):
-            # Now we've gotten a library, but we'll need to figure out the
-            # includes if this is going to work.  It feels like there is a
-            # better way to pull off two directory names.
-            freetype_dir = os.path.dirname(os.path.dirname(freetype_libfile))
-            if os.path.isdir(os.path.join(freetype_dir, "include")) and \
-               os.path.isfile(os.path.join(freetype_dir, "include", "ft2build.h")):
-                freetype_inc = os.path.join(freetype_dir, "include")
-                freetype_lib = os.path.join(freetype_dir, "lib")
-                print "FTYPE_LOCATION: freetype found in: %s, %s" % (freetype_inc, freetype_lib)
-                return freetype_inc, freetype_lib
-    except ImportError:
-        pass
-    # X11 is where it's located by default on OSX, although I am slightly
-    # reluctant to link against that one.
-    for freetype_dir in ["/usr/", "/usr/local/", "/usr/X11/"]:
-        if os.path.isfile(os.path.join(freetype_dir, "include", "ft2build.h")):
-            if os.path.isdir(os.path.join(freetype_dir, "include")) and \
-               os.path.isfile(os.path.join(freetype_dir, "include", "ft2build.h")):
-                freetype_inc = os.path.join(freetype_dir, "include")
-                freetype_lib = os.path.join(freetype_dir, "lib")
-                print "FTYPE_LOCATION: freetype found in: %s, %s" % (freetype_inc, freetype_lib)
-                return freetype_inc, freetype_lib
-    print "Reading freetype location from freetype.cfg failed."
-    print "Please place the base directory of your freetype install in freetype.cfg and restart."
-    print "(ex: \"echo '/usr/local/' > freetype.cfg\" )"
-    print "You can locate this by looking for the file ft2build.h"
-    sys.exit(1)
+    return check_for_dependencies(
+        "FTYPE_DIR", "freetype.cfg", "ft2build.h", "freetype"
+    )
+
 
 def check_for_openmp():
     # Create a temporary directory
@@ -122,7 +40,7 @@ def check_for_openmp():
     with open(os.devnull, 'w') as fnull:
         exit_code = subprocess.call([compiler, '-fopenmp', filename],
                                     stdout=fnull, stderr=fnull)
-        
+
     # Clean up
     file.close()
     os.chdir(curdir)
@@ -249,6 +167,10 @@ def configuration(parent_package='',top_path=None):
     config.add_extension("GridTree", 
     ["yt/utilities/lib/GridTree.pyx"],
         libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
+    config.add_extension("amr_kdtools", 
+                         ["yt/utilities/lib/amr_kdtools.pyx"],
+                         libraries=["m"], depends=["yt/utilities/lib/fp_utils.pxd"])
+    config.add_subpackage("tests")
 
     if os.environ.get("GPERFTOOLS", "no").upper() != "NO":
         gpd = os.environ["GPERFTOOLS"]
