@@ -40,9 +40,10 @@ mpc_per_pc    = 1e-6
 mpc_per_au    = 4.84813682e-12
 mpc_per_rsun  = 2.253962e-14
 mpc_per_miles = 5.21552871e-20
+mpc_per_km    = 3.24077929e-20
 mpc_per_cm    = 3.24077929e-25
 kpc_per_cm    = mpc_per_cm / mpc_per_kpc
-km_per_pc     = 1.3806504e13
+km_per_pc     = 3.08567758e13
 km_per_m      = 1e-3
 km_per_cm     = 1e-5
 pc_per_cm     = 3.24077929e-19
@@ -54,6 +55,7 @@ pc_per_mpc    = 1.0 / mpc_per_pc
 au_per_mpc    = 1.0 / mpc_per_au
 rsun_per_mpc  = 1.0 / mpc_per_rsun
 miles_per_mpc = 1.0 / mpc_per_miles
+km_per_mpc    = 1.0 / mpc_per_km
 cm_per_mpc    = 1.0 / mpc_per_cm
 cm_per_kpc    = 1.0 / kpc_per_cm
 cm_per_km     = 1.0 / km_per_cm
