@@ -129,7 +129,16 @@ class VelocityCallback(PlotCallback):
         else:
             xv = "%s-velocity" % (x_names[plot.data.axis])
             yv = "%s-velocity" % (y_names[plot.data.axis])
-            qcb = QuiverCallback(xv, yv, self.factor, scale=self.scale, scale_units=self.scale_units, normalize=self.normalize)
+
+            bv = plot.data.get_field_parameter("bulk_velocity")
+            if bv is not None:
+                bv_x = bv[x_dict[plot.data.axis]]
+                bv_y = bv[y_dict[plot.data.axis]]
+            else: bv_x = bv_y = 0
+
+            qcb = QuiverCallback(xv, yv, self.factor, scale=self.scale, 
+                                 scale_units=self.scale_units, 
+                                 normalize=self.normalize, bv_x=bv_x, bv_y=bv_y)
         return qcb(plot)
 
 class MagFieldCallback(PlotCallback):
@@ -174,11 +183,12 @@ class QuiverCallback(PlotCallback):
     (see matplotlib.axes.Axes.quiver for more info)
     """
     _type_name = "quiver"
-    def __init__(self, field_x, field_y, factor=16, scale=None, scale_units=None, normalize=False):
+    def __init__(self, field_x, field_y, factor=16, scale=None, scale_units=None, normalize=False, bv_x=0, bv_y=0):
         PlotCallback.__init__(self)
         self.field_x = field_x
         self.field_y = field_y
-        self.bv_x = self.bv_y = 0
+        self.bv_x = bv_x
+        self.bv_y = bv_y
         self.factor = factor
         self.scale = scale
         self.scale_units = scale_units
@@ -219,7 +229,7 @@ class QuiverCallback(PlotCallback):
 
 class ContourCallback(PlotCallback):
     """
-    annotate_contour(self, field, ncont=5, factor=4, take_log=False, clim=None,
+    annotate_contour(self, field, ncont=5, factor=4, take_log=None, clim=None,
                      plot_args = None):
 
     Add contours in *field* to the plot.  *ncont* governs the number of
@@ -229,7 +239,8 @@ class ContourCallback(PlotCallback):
     """
     _type_name = "contour"
     def __init__(self, field, ncont=5, factor=4, clim=None,
-                 plot_args = None, label = False, label_args = None):
+                 plot_args = None, label = False, take_log = None, 
+                 label_args = None):
         PlotCallback.__init__(self)
         self.ncont = ncont
         self.field = field
@@ -237,6 +248,7 @@ class ContourCallback(PlotCallback):
         from yt.utilities.delaunay.triangulate import Triangulation as triang
         self.triang = triang
         self.clim = clim
+        self.take_log = take_log
         if plot_args is None: plot_args = {'colors':'k'}
         self.plot_args = plot_args
         self.label = label
@@ -303,9 +315,12 @@ class ContourCallback(PlotCallback):
         elif plot._type_name == 'OffAxisProjection':
             zi = plot.frb[self.field][::self.factor,::self.factor].transpose()
         
-        if plot.pf.field_info[self.field].take_log: zi=np.log10(zi)
+        if self.take_log is None:
+            self.take_log = plot.pf.field_info[self.field].take_log
 
-        if plot.pf.field_info[self.field].take_log and self.clim is not None: 
+        if self.take_log: zi=np.log10(zi)
+
+        if self.take_log and self.clim is not None: 
             self.clim = (np.log10(self.clim[0]), np.log10(self.clim[1]))
         
         if self.clim is not None: 
