@@ -717,7 +717,7 @@ class PWViewer(PlotWindow):
             cbname = callback_registry[key]._type_name
             CallbackMaker = callback_registry[key]
             callback = invalidate_plot(apply_callback(CallbackMaker))
-            callback.__doc__ = CallbackMaker.__init__.__doc__
+            callback.__doc__ = CallbackMaker.__doc__
             self.__dict__['annotate_'+cbname] = types.MethodType(callback,self)
 
     @invalidate_plot
